==> jbidibc-decoder-1.13.8-test-sources.jar: org/bidib/jbidibc/decoder/schema/decoderfirmware/DecoderFirmwareDefinitionTest.java <==
package org.bidib.jbidibc.decoder.schema.decoderfirmware;

import org.bidib.jbidibc.core.schema.exception.InvalidContentException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.testng.Assert;
import org.testng.annotations.Test;

public class DecoderFirmwareDefinitionTest {
    private static final Logger LOGGER = LoggerFactory.getLogger(DecoderFirmwareDefinitionTest.class);

    @Test
    public void loadFirmwareDefinition2() {
        String filePath = "/firmware/97/Firmware_97_1.06_sound.xml";

        filePath = DecoderFirmwareDefinitionTest.class.getResource(filePath).getPath();
        LOGGER.info("Load firmwareDefinition from path: {}", filePath);

        DecoderFirmwareDefinitionFactory factory = new DecoderFirmwareDefinitionFactory();
        DecoderFirmwareDefinition firmwareDefinition = factory.loadFirmwareDefinition(filePath);

        Assert.assertNotNull(firmwareDefinition);
    }

    @Test(expectedExceptions = InvalidContentException.class)
    public void loadFirmwareDefinition3() {
        String filePath = "/firmware/invalid/Firmware_invalid_1.0.xml";

        filePath = DecoderFirmwareDefinitionTest.class.getResource(filePath).getPath();
        LOGGER.info("Load firmwareDefinition from path: {}", filePath);

        DecoderFirmwareDefinitionFactory factory = new DecoderFirmwareDefinitionFactory();
        DecoderFirmwareDefinition firmwareDefinition = factory.loadFirmwareDefinition(filePath);

        Assert.assertNotNull(firmwareDefinition);
    }

    @Test
    public void loadFirmwareDefinition4() {
        String filePath = "/firmware/97/Firmware_97_3.06.xml";

        filePath = DecoderFirmwareDefinitionTest.class.getResource(filePath).getPath();
        LOGGER.info("Load firmwareDefinition from path: {}", filePath);

        DecoderFirmwareDefinitionFactory factory = new DecoderFirmwareDefinitionFactory();
        DecoderFirmwareDefinition firmwareDefinition = factory.loadFirmwareDefinition(filePath);

        Assert.assertNotNull(firmwareDefinition);
    }
}

==> jbidibc-decoder-2.0.4-test-sources.jar: org/bidib/jbidibc/decoder/schema/decoderfirmware/DecoderFirmwareDefinitionTest.java <==
package org.bidib.jbidibc.decoder.schema.decoderfirmware;

import org.assertj.core.api.Assertions;
import org.bidib.jbidibc.core.schema.exception.InvalidContentException;
import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DecoderFirmwareDefinitionTest {
    private static final Logger LOGGER = LoggerFactory.getLogger(DecoderFirmwareDefinitionTest.class);

    @Test
    public void loadFirmwareDefinition2() {
        String filePath = "/firmware/97/Firmware_97_1.06_sound.xml";

        filePath = DecoderFirmwareDefinitionTest.class.getResource(filePath).getPath();
        LOGGER.info("Load firmwareDefinition from path: {}", filePath);

        DecoderFirmwareDefinitionFactory factory = new DecoderFirmwareDefinitionFactory();
        DecoderFirmwareDefinition firmwareDefinition = factory.loadFirmwareDefinition(filePath);

        Assertions.assertThat(firmwareDefinition).isNotNull();
    }

    @Test
    public void loadFirmwareDefinition3() {
        String filePath = "/firmware/invalid/Firmware_invalid_1.0.xml";

        final String resourcePath = DecoderFirmwareDefinitionTest.class.getResource(filePath).getPath();
        LOGGER.info("Load firmwareDefinition from path: {}", resourcePath);

        DecoderFirmwareDefinitionFactory factory = new DecoderFirmwareDefinitionFactory();

        Assertions
            .assertThatThrownBy(() -> factory.loadFirmwareDefinition(resourcePath))
            .isInstanceOf(InvalidContentException.class);
    }

    @Test
    public void loadFirmwareDefinition4() {
        String filePath = "/firmware/97/Firmware_97_3.06.xml";

        filePath = DecoderFirmwareDefinitionTest.class.getResource(filePath).getPath();
        LOGGER.info("Load firmwareDefinition from path: {}", filePath);

        DecoderFirmwareDefinitionFactory factory = new DecoderFirmwareDefinitionFactory();
        DecoderFirmwareDefinition firmwareDefinition = factory.loadFirmwareDefinition(filePath);

        Assertions.assertThat(firmwareDefinition).isNotNull();
    }
}
